<?php

/**
 * Forprofit Theme Customizer
 */

// Loads custom control
require trailingslashit(get_template_directory()) . 'inc/customizer/controls/custom-text.php';

// Loads the customizer settings
require trailingslashit(get_template_directory()) . 'inc/customizer/general.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/header.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/post.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/page.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/footer.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/featured.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/callout.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/fonts.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/colors.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/layouts.php';
require trailingslashit(get_template_directory()) . 'inc/customizer/retina-logo.php';

/**
 * Custom customizer functions.
 */
function forprofit_customize_functions($wp_customize) {

    // Register new panel: Design
    $wp_customize->add_panel('forprofit_design', array(
        'title'       => esc_html__('Theme Design', 'forprofit'),
        'description' => esc_html__('This panel is used for customizing the design of your site.', 'forprofit'),
        'priority'    => 125,
    ));

    // Register new panel: Theme Options
    $wp_customize->add_panel('forprofit_options', array(
        'title'       => esc_html__('Theme Options', 'forprofit'),
        'description' => esc_html__('This panel is used for customizing the Forprofit theme.', 'forprofit'),
        'priority'    => 130,
    ));

    // Live preview of Site Title
    $wp_customize->get_setting('blogname')->transport = 'postMessage';

    // Enable selective refresh to the Site Title
    if (isset($wp_customize->selective_refresh)) {
        $wp_customize->selective_refresh->add_partial('blogname', array(
            'selector'            => '.site-title a',
            'settings'         => array('blogname'),
            'render_callback'  => function () {
                return get_bloginfo('name', 'display');
            }
        ));
    }

    // Move the Colors section.
    $wp_customize->get_section('colors')->panel    = 'forprofit_design';
    $wp_customize->get_section('colors')->priority = 1;

    // Move the Background Image section.
    $wp_customize->get_section('background_image')->panel    = 'forprofit_design';
    $wp_customize->get_section('background_image')->priority = 7;

    // Move the Additional CSS section.
    $wp_customize->get_section('custom_css')->panel    = 'forprofit_design';
    $wp_customize->get_section('custom_css')->priority = 9;

    // Move background color to background image section.
    $wp_customize->get_section('background_image')->title = esc_html__('Background', 'forprofit');
    $wp_customize->get_control('background_color')->section = 'background_image';
}
add_action('customize_register', 'forprofit_customize_functions', 99);

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function forprofit_customize_preview_js() {
    wp_enqueue_script('forprofit-customizer', get_template_directory_uri() . '/assets/js/customizer/customizer.js', array('customize-preview', 'jquery'));
}
add_action('customize_preview_init', 'forprofit_customize_preview_js');

/**
 * Custom styles.
 */
function forprofit_custom_css() {

    // Set up empty variable.
    $css = '';

    // Get the customizer value.
    $color           = get_theme_mod('forprofit_accent_color', '#54b5e5');
    $heading_font    = get_theme_mod('forprofit_heading_font_family', '\'Poppins\', sans-serif');
    $body_font       = get_theme_mod('forprofit_body_font_family', '\'Poppins\', sans-serif');

    if ($color != '#54b5e5') {
        $css .= '
		.button-primary,.social-links,.menu-primary-items .sub-menu,.page-header,.tag-links a:hover,.search-toggle:hover {
			background-color: ' . sanitize_hex_color($color) . ';
		}

		.cat-link a,h2.entry-title a:hover,.entry-meta a:hover,.posts-thumbnail-widget .post-title:hover,.copyright a,.menu-footer-items a:hover,.page-header .cat-link a:hover,.page-header .entry-meta a:hover,.author-bio .name a:hover,.logged-in-as a,.entry-content a,.info-right .to-top:hover {
			color: ' . sanitize_hex_color($color) . ';
		}

		.menu-primary-items li:hover {
			border-color: ' . sanitize_hex_color($color) . ';
		}
		';
    }

    if ($heading_font != '\'Poppins\', sans-serif') {
        $css .= '
			h1, h2, h3, h4, h5, h6, .entry-author {
				font-family: ' . esc_attr($heading_font) . ';
			}
		';
    }

    if ($body_font != '\'Poppins\', sans-serif') {
        $css .= '
			body {
				font-family: ' . esc_attr($body_font) . ';
			}
		';
    }

    // Print the custom style
    wp_add_inline_style('forprofit-style', $css);
}
add_action('wp_enqueue_scripts', 'forprofit_custom_css');

/**
 * Enable sticky header
 */
function forprofit_sticky_header() {

    // Get the customizer data
    $enable = get_theme_mod('forprofit_sticky_header', 1);

    if (!$enable) {
        return;
    }

    $css = '.site-header {position: fixed;top: 0;width: 100%;z-index: 9;min-height: 7.5rem;} .featured, .page-header{margin-top: 7.5rem;}';

    wp_add_inline_style('forprofit-style', $css);
}
add_action('wp_enqueue_scripts', 'forprofit_sticky_header');

/**
 * Enable sticky sidebar
 */
function forprofit_sticky_sidebar() {

    // Get the customizer data
    $enable = get_theme_mod('forprofit_sticky_sidebar', 1);

    if ($enable) {
?>
        <script type="text/javascript">
            (function($) {
                $(function() {
                    $('.widget-area').theiaStickySidebar({
                        additionalMarginTop: 100
                    });
                });
            }(jQuery));
        </script>
<?php
    }
}
add_action('wp_footer', 'forprofit_sticky_sidebar', 15);

/**
 * Sanitize the Footer Credits
 */
function forprofit_sanitize_textarea($text) {
    if (current_user_can('unfiltered_html')) {
        $text = $text;
    } else {
        $text = wp_kses_post($text);
    }
    return $text;
}
