<?php

/**
 * Callout Customizer
 */

/**
 * Register the customizer.
 */
function forprofit_callout_customize_register($wp_customize) {

    // Register new section: Callout
    $wp_customize->add_section('forprofit_callout', array(
        'title'       => esc_html__('Callout', 'forprofit'),
        'description' => esc_html__('This area called Callout, it appears at the bottom of the Featured area.', 'forprofit'),
        'panel'       => 'forprofit_options',
        'priority'    => 11
    ));

    // Register callout type setting
    $wp_customize->add_setting('forprofit_callout_type', array(
        'default'           => 'subscribe',
        'sanitize_callback' => 'forprofit_sanitize_select',
    ));
    $wp_customize->add_control('forprofit_callout_type', array(
        'label'             => esc_html__('Type', 'forprofit'),
        'section'           => 'forprofit_callout',
        'priority'          => 1,
        'type'              => 'radio',
        'choices'           => array(
            'subscribe' => esc_html__('Subscribe Box', 'forprofit'),
            'posts'     => esc_html__('Posts List', 'forprofit')
        )
    ));

    // Register subscribe box info setting
    $wp_customize->add_setting('forprofit_subscribe_info', array(
        'default'           => '',
        'sanitize_callback' => 'esc_attr'
    ));
    $wp_customize->add_control(new Forprofit_Custom_Text($wp_customize, 'forprofit_subscribe_info', array(
        'label'             => esc_html__('Subscribe Box', 'forprofit'),
        'description'       => esc_html__('To display the form, please use the shortcode provided by Mailchimp for WordPress plugin.', 'forprofit'),
        'section'           => 'forprofit_callout',
        'priority'          => 3,
        'active_callback'   => 'forprofit_is_callout_subscribe'
    )));

    // Register subscribe box title setting
    $wp_customize->add_setting('forprofit_subscribe_title', array(
        'default'           => '',
        'sanitize_callback' => 'forprofit_sanitize_html',
    ));
    $wp_customize->add_control('forprofit_subscribe_title', array(
        'label'             => esc_html__('Title', 'forprofit'),
        'section'           => 'forprofit_callout',
        'priority'          => 5,
        'type'              => 'text',
        'active_callback'   => 'forprofit_is_callout_subscribe'
    ));

    // Register subscribe box title setting
    $wp_customize->add_setting('forprofit_subscribe_subtitle', array(
        'default'           => '',
        'sanitize_callback' => 'forprofit_sanitize_html',
    ));
    $wp_customize->add_control('forprofit_subscribe_subtitle', array(
        'label'             => esc_html__('Sub Title', 'forprofit'),
        'section'           => 'forprofit_callout',
        'priority'          => 7,
        'type'              => 'text',
        'active_callback'   => 'forprofit_is_callout_subscribe'
    ));

    // Register subscribe box shortcode setting
    $wp_customize->add_setting('forprofit_subscribe_shortcode', array(
        'default'           => '',
        'sanitize_callback' => 'forprofit_sanitize_html',
    ));
    $wp_customize->add_control('forprofit_subscribe_shortcode', array(
        'label'             => esc_html__('Form Shortcode', 'forprofit'),
        'section'           => 'forprofit_callout',
        'priority'          => 9,
        'type'              => 'text',
        'active_callback'   => 'forprofit_is_callout_subscribe'
    ));

    // Register callout posts info setting
    $wp_customize->add_setting('forprofit_callout_posts_info', array(
        'default'           => '',
        'sanitize_callback' => 'esc_attr'
    ));
    $wp_customize->add_control(new Forprofit_Custom_Text($wp_customize, 'forprofit_callout_posts_info', array(
        'label'             => esc_html__('Posts', 'forprofit'),
        'description'       => esc_html__('Display latest 4 posts from tag you choose.', 'forprofit'),
        'section'           => 'forprofit_callout',
        'priority'          => 11,
        'active_callback'   => 'forprofit_is_callout_posts'
    )));

    // Register callout posts tag name setting
    $wp_customize->add_setting('forprofit_callout_posts_tag', array(
        'default'           => 'editors choice',
        'sanitize_callback' => 'forprofit_sanitize_html',
    ));
    $wp_customize->add_control('forprofit_callout_posts_tag', array(
        'label'             => esc_html__('Tag name', 'forprofit'),
        'section'           => 'forprofit_callout',
        'priority'          => 15,
        'type'              => 'text',
        'active_callback'   => 'forprofit_is_callout_posts'
    ));
}
add_action('customize_register', 'forprofit_callout_customize_register');

/**
 * Active callback option if callout is subscribe
 */
function forprofit_is_callout_subscribe() {

    $option = get_theme_mod('forprofit_callout_type', 'subscribe');

    if ($option == 'subscribe') {
        return true;
    } else {
        return false;
    }
}

/**
 * Active callback option if callout is posts
 */
function forprofit_is_callout_posts() {

    $option = get_theme_mod('forprofit_callout_type', 'subscribe');

    if ($option == 'posts') {
        return true;
    } else {
        return false;
    }
}
